==> auto_mappr-1.5.0.tar.gz: test/integration/fixture/enum_mapping.dart <==
import 'package:auto_mappr_annotation/auto_mappr_annotation.dart';

part 'enum_mapping.g.dart';

enum Person { student, parent, employee }

enum User { student, parent, employee, admin }

enum LocalPerson { student, parent, employee, unknown }

enum RemotePerson { student, parent, employee, vp, director }

enum EnhancedSource {
  student(1, 'student'),
  parent(2, 'parent'),
  employee(3, 'employee');

  const EnhancedSource(this.id, this.name);

  final int id;
  final String name;

  String get row => '$id+$name';
}

enum EnhancedSourceWithUnknown {
  student(1, 'student'),
  parent(2, 'parent'),
  employee(3, 'employee'),
  alien(4, 'alien');

  const EnhancedSourceWithUnknown(this.id, this.name);

  final int id;
  final String name;

  String get row => '$id+$name';
}

enum EnhancedTarget {
  student(1, 'student', isAdmin: false),
  parent(2, 'parent', isAdmin: false),
  employee(3, 'employee', isAdmin: false),
  admin(4, 'admin', isAdmin: true),
  unknown(5, 'unknown', isAdmin: false);

  const EnhancedTarget(this.id, this.name, {required this.isAdmin});

  final int id;
  final String name;
  final bool isAdmin;

  String get row => '$id+$name';
}

LocalPerson _localRemoteUnknownDefault() => LocalPerson.unknown;

@AutoMappr([
  MapType<Person, User>(),
  MapType<RemotePerson, LocalPerson>(
    whenSourceIsNull: _localRemoteUnknownDefault,
  ),
  MapType<EnhancedSource, EnhancedTarget>(),
  MapType<EnhancedSourceWithUnknown, EnhancedTarget>(
    whenSourceIsNull: EnhancedTarget.unknown,
  ),
])
class Mappr extends $Mappr {
  const Mappr();
}

==> auto_mappr-2.1.0.tar.gz: test/integration/fixture/enum_mapping.dart <==
import 'package:auto_mappr_annotation/auto_mappr_annotation.dart';

import 'enum_mapping.auto_mappr.dart';

enum Person { employee, parent, student }

enum User { admin, employee, parent, student }

enum LocalPerson { employee, parent, student, unknown }

enum RemotePerson { director, employee, parent, student, vp }

enum EnhancedSource {
  employee(3, 'employee'),
  parent(2, 'parent'),
  student(1, 'student');

  const EnhancedSource(this.id, this.name);

  final int id;
  final String name;

  String get row => '$id+$name';
}

enum EnhancedSourceWithUnknown {
  alien(4, 'alien'),
  employee(3, 'employee'),
  parent(2, 'parent'),
  student(1, 'student');

  const EnhancedSourceWithUnknown(this.id, this.name);

  final int id;
  final String name;

  String get row => '$id+$name';
}

enum EnhancedTarget {
  admin(4, 'admin', isAdmin: true),
  employee(3, 'employee', isAdmin: false),
  parent(2, 'parent', isAdmin: false),
  student(1, 'student', isAdmin: false),
  unknown(5, 'unknown', isAdmin: false);

  const EnhancedTarget(this.id, this.name, {required this.isAdmin});

  final int id;
  final String name;
  final bool isAdmin;

  String get row => '$id+$name';
}

// ignore: prefer-static-class, for testing
LocalPerson localRemoteUnknownDefault() => LocalPerson.unknown;

@AutoMappr([
  MapType<Person, User>(),
  MapType<RemotePerson, LocalPerson>(
    whenSourceIsNull: localRemoteUnknownDefault,
  ),
  MapType<EnhancedSource, EnhancedTarget>(),
  MapType<EnhancedSourceWithUnknown, EnhancedTarget>(
    whenSourceIsNull: EnhancedTarget.unknown,
  ),
])
class Mappr extends $Mappr {
  const Mappr();
}
